@@ -1,21 +1,26 @@
 package Catalyst::Model::REST::Serializer;
 BEGIN {
-  $Catalyst::Model::REST::Serializer::VERSION = '0.16';
+  $Catalyst::Model::REST::Serializer::VERSION = '0.17';
 }
 use 5.010;
 use Try::Tiny;
 use Moose;
 use Moose::Util::TypeConstraints;
 
-with 'Data::Serializable' => { -version => '0.40.1' };
+use Data::Serializer;
 
 has 'type' => (
     isa => enum ([qw{application/json application/xml application/yaml application/x-www-form-urlencoded}]),
     is  => 'rw',
 	default => 'application/json',
-	trigger   => \&_set_module
 );
 no Moose::Util::TypeConstraints;
+has 'serializer' => (
+	isa => 'Data::Serializer',
+	is => 'ro',
+	default => \&_set_serializer,
+	lazy => 1,
+);
 
 no Moose;
 
@@ -34,20 +39,16 @@ our %modules = (
 	},
 );
 
-sub _set_module {
-	my ($self, $type) = @_;
-	return unless $modules{$type};
+sub _set_serializer {
+	my $self = shift;
+	return unless $modules{$self->type};
 
-	my $module = $modules{$type}{module};
+	my $module = $modules{$self->type}{module};
 	return $module if $module eq 'FORM';
 
-	my $serializer;
-	try {
-		$serializer = $self->serializer_module($module);
-	} catch {
-		$serializer = undef;
-	};
-	return $serializer;
+	return Data::Serializer->new(
+		serializer => $module,
+	);
 }
 
 sub content_type {
@@ -55,6 +56,16 @@ sub content_type {
 	return $self->type;
 }
 
+sub serialize {
+	my ($self, $data) = @_;
+	return $self->serializer ? $self->serializer->raw_serialize($data) : undef;
+}
+
+sub deserialize {
+	my ($self, $data) = @_;
+	return $self->serializer ? $self->serializer->raw_deserialize($data) : undef;
+}
+
 1;
 
 __END__
@@ -66,7 +77,7 @@ Catalyst::Model::REST::Serializer
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 AUTHOR
 
